/* dialog.h
 *
 * Pieter Eendebak <pte@ddsw.nl>
 *
 */

#ifndef DIALOG_H
#define DIALOG_H

#include "datafile.h"
#include "includes.h"

/**
 * Misc is a class used by KFortune for setting various options.
 * These options are :
 * <pre>
 * - Launch KFortune on startup?
 * - Show offensive fortunes?
 * - Way of choosing a fortune from database
 * - Exit the program after a set time?
 * </pre>
 *
 * @short Class for setting various options.
 * @author Pieter Eendebak <pte@ddsw.nl>
 */
class Misc : public QDialog
{

	Q_OBJECT

public:
 	Misc ( int l, int o, int a, int t, int c, int d, int b,
		QWidget *, const char *name);
 	~Misc();

	QGroupBox *box;
	
	QCheckBox *displayBox, *buttonsBox,
		*offensiveBox, *choosingBox;
	
	QCheckBox *launchBox, *autoexitBox;
	QLabel *time, *counter; 
	QScrollBar *scroll;
	int tijd;	

public slots:
	void changeTime(int);
	void changeAutoexitBox(bool state);

	void launch( int ) ;
	int launch() ;
	void offensive( int ) ;
	int offensive() ;
	void choosing( int ) ;
	int choosing() ;
	void autoexit( int ) ;
	int autoexit() ;
	void display( int ) ;
	int display() ;
	void buttons( int ) ;
	int buttons() ;

private:
	
	QPushButton *ok, *cancel;
};

/**
 * Dialog for editing the KFortune database.
 *
 * @short Dialog for editing the KFortune database.
 * @author Pieter Eendebak <pte@ddsw.nl>
 */
class DataBase : public QDialog
{

        Q_OBJECT

public:
        DataBase ( int off, KConfig *, QWidget *, const char *name);
        ~DataBase();

	QGroupBox *box;
	
	QLabel *naam, *number;	

	QCheckBox **rows;
	QLabel **rownumbers;

	QLabel *label;

private:

	QPushButton *ok, *cancel;
};

/**
 * This class is used for showing a 'About'-window. I'm not using
 * QMessageBox or KMsgBox because I want to show a picture and
 * have some control on how the box is displayed.
 *
 * @param icon The icon to be shown
 *
 */
class About : public QDialog
{
	Q_OBJECT
public:
	About(QPixmap *icon, QWidget *parent=0, const char *name=0);
	~About();

private:
	QPushButton *ok;
};
#endif		
